@@ -20,11 +20,6 @@
 #include "pixbuf-document.h"
 #include "ev-document-thumbnails.h"
 
-enum {
-	PROP_0,
-	PROP_TITLE
-};
-
 struct _PixbufDocumentClass
 {
 	GObjectClass parent_class;
@@ -35,10 +30,7 @@ struct _PixbufDocument
 	GObject parent_instance;
 
 	GdkPixbuf *pixbuf;
-	GdkDrawable *target;
-	gdouble scale;
-
-	gint x_offset, y_offset;
+	EvOrientation orientation;
 };
 
 typedef struct _PixbufDocumentClass PixbufDocumentClass;
@@ -93,92 +85,74 @@ pixbuf_document_get_n_pages (EvDocument  *document)
 	return 1;
 }
 
-static void
-pixbuf_document_set_page (EvDocument  *document,
-			  int          page)
-{
-	/* Do nothing */
-}
-
-static int
-pixbuf_document_get_page (EvDocument  *document)
-{
-	return 1;
-}
-
-static void
-pixbuf_document_set_target (EvDocument  *document,
-			    GdkDrawable *target)
+static EvOrientation
+pixbuf_document_get_orientation (EvDocument *document)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
 
-	pixbuf_document->target = target;
+	return pixbuf_document->orientation;
 }
 
 static void
-pixbuf_document_set_scale (EvDocument  *document,
-			   double       scale)
+pixbuf_document_set_orientation (EvDocument *document,
+			         EvOrientation   orientation)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
 
-	pixbuf_document->scale = scale;
+	pixbuf_document->orientation = orientation;
 }
 
-static void
-pixbuf_document_set_page_offset (EvDocument  *document,
-			      int          x,
-			      int          y)
+static GdkPixbuf *
+rotate_pixbuf (EvDocument *document, GdkPixbuf *pixbuf)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
 
-	pixbuf_document->x_offset = x;
-	pixbuf_document->y_offset = y;
+	switch (pixbuf_document->orientation)
+	{
+		case EV_ORIENTATION_LANDSCAPE:
+			return gdk_pixbuf_rotate_simple (pixbuf, 90);
+		case EV_ORIENTATION_UPSIDEDOWN:
+			return gdk_pixbuf_rotate_simple (pixbuf, 180);
+		case EV_ORIENTATION_SEASCAPE:
+			return gdk_pixbuf_rotate_simple (pixbuf, 270);
+		default:
+			return g_object_ref (pixbuf);
+	}
 }
 
 static void
 pixbuf_document_get_page_size (EvDocument   *document,
 			       int           page,
-			       int          *width,
-			       int          *height)
+			       double       *width,
+			       double       *height)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
 
-	if (width)
-		*width = gdk_pixbuf_get_width (pixbuf_document->pixbuf) * pixbuf_document->scale;
-	if (height)
-		*height = gdk_pixbuf_get_height (pixbuf_document->pixbuf) * pixbuf_document->scale;
+	if (pixbuf_document->orientation == EV_ORIENTATION_PORTRAIT ||
+	    pixbuf_document->orientation ==  EV_ORIENTATION_UPSIDEDOWN) {
+		*width = gdk_pixbuf_get_width (pixbuf_document->pixbuf);
+		*height = gdk_pixbuf_get_height (pixbuf_document->pixbuf);
+	} else {
+		*width = gdk_pixbuf_get_height (pixbuf_document->pixbuf);
+		*height = gdk_pixbuf_get_width (pixbuf_document->pixbuf);
+	}
 }
 
-static void
-pixbuf_document_render (EvDocument  *document,
-			int          clip_x,
-			int          clip_y,
-			int          clip_width,
-			int          clip_height)
+static GdkPixbuf*
+pixbuf_document_render_pixbuf (EvDocument  *document, int page, double scale)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
-	GdkPixbuf *tmp_pixbuf;
-	
-	tmp_pixbuf = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (pixbuf_document->pixbuf),
-				     gdk_pixbuf_get_has_alpha (pixbuf_document->pixbuf),
-				     gdk_pixbuf_get_bits_per_sample (pixbuf_document->pixbuf),
-				     clip_width, clip_height);
-	
-	gdk_pixbuf_fill (tmp_pixbuf, 0xffffffff);
-	gdk_pixbuf_scale (pixbuf_document->pixbuf, tmp_pixbuf, 0, 0,
-			  MIN(gdk_pixbuf_get_width(pixbuf_document->pixbuf)* pixbuf_document->scale-clip_x, clip_width),
-			  MIN(gdk_pixbuf_get_height(pixbuf_document->pixbuf)* pixbuf_document->scale-clip_y, clip_height),
-			  -clip_x, -clip_y,
-			  pixbuf_document->scale, pixbuf_document->scale,
-			  GDK_INTERP_BILINEAR);
-	
-	gdk_draw_pixbuf (pixbuf_document->target, NULL, tmp_pixbuf,
-			 0, 0,
-			 clip_x, clip_y,
-			 clip_width, clip_height, GDK_RGB_DITHER_NORMAL,
-			 0, 0);
+	GdkPixbuf *scaled_pixbuf, *rotated_pixbuf;
 
-	g_object_unref (tmp_pixbuf);
+	scaled_pixbuf = gdk_pixbuf_scale_simple (pixbuf_document->pixbuf,
+					         gdk_pixbuf_get_width (pixbuf_document->pixbuf) * scale,
+					         gdk_pixbuf_get_height (pixbuf_document->pixbuf) * scale,
+					         GDK_INTERP_BILINEAR);
+
+	rotated_pixbuf = rotate_pixbuf (document, scaled_pixbuf);
+	g_object_unref (scaled_pixbuf);
+
+	return rotated_pixbuf;
 }
 
 static void
@@ -191,61 +165,29 @@ pixbuf_document_finalize (GObject *object)
 	G_OBJECT_CLASS (pixbuf_document_parent_class)->finalize (object);
 }
 
-static void
-pixbuf_document_set_property (GObject *object,
-		              guint prop_id,
-			      const GValue *value,
-			      GParamSpec *pspec)
-{
-	switch (prop_id)
-	{
-		case PROP_TITLE:
-			/* read only */
-			break;
-	}
-}
-
-static void
-pixbuf_document_get_property (GObject *object,
-		              guint prop_id,
-		              GValue *value,
-		              GParamSpec *pspec)
-{
-	switch (prop_id)
-	{
-		case PROP_TITLE:
-			g_value_set_string (value, NULL);
-			break;
-	}
-}
-
 static void
 pixbuf_document_class_init (PixbufDocumentClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
 	gobject_class->finalize = pixbuf_document_finalize;
-	gobject_class->get_property = pixbuf_document_get_property;
-	gobject_class->set_property = pixbuf_document_set_property;
-
-	g_object_class_override_property (gobject_class, PROP_TITLE, "title");
 }
 
-static char *
-pixbuf_document_get_text (EvDocument *document, GdkRectangle *rect)
+static gboolean
+pixbuf_document_can_get_text (EvDocument *document)
 {
-	/* FIXME this method should not be in EvDocument */
-	g_warning ("pixbuf_document_get_text not implemented");
-	return NULL;
+	return FALSE;
 }
 
-
-static EvLink *
-pixbuf_document_get_link (EvDocument *document,
-		          int         x,
-		          int	      y)
+static EvDocumentInfo *
+pixbuf_document_get_info (EvDocument *document)
 {
-	return NULL;
+	EvDocumentInfo *info;
+
+	info = g_new0 (EvDocumentInfo, 1);
+	info->fields_mask = 0;
+
+	return info;
 }
 
 static void
@@ -253,16 +195,13 @@ pixbuf_document_document_iface_init (EvDocumentIface *iface)
 {
 	iface->load = pixbuf_document_load;
 	iface->save = pixbuf_document_save;
-	iface->get_text = pixbuf_document_get_text;
-	iface->get_link = pixbuf_document_get_link;
+	iface->can_get_text = pixbuf_document_can_get_text;
 	iface->get_n_pages = pixbuf_document_get_n_pages;
-	iface->set_page = pixbuf_document_set_page;
-	iface->get_page = pixbuf_document_get_page;
-	iface->set_scale = pixbuf_document_set_scale;
-	iface->set_target = pixbuf_document_set_target;
-	iface->set_page_offset = pixbuf_document_set_page_offset;
 	iface->get_page_size = pixbuf_document_get_page_size;
-	iface->render = pixbuf_document_render;
+	iface->render_pixbuf = pixbuf_document_render_pixbuf;
+	iface->get_info = pixbuf_document_get_info;
+	iface->get_orientation = pixbuf_document_get_orientation;
+	iface->set_orientation = pixbuf_document_set_orientation;
 }
 
 static GdkPixbuf *
@@ -313,8 +252,4 @@ pixbuf_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface
 static void
 pixbuf_document_init (PixbufDocument *pixbuf_document)
 {
-	pixbuf_document->scale = 1.0;
-
-	pixbuf_document->x_offset = 0;
-	pixbuf_document->y_offset = 0;
 }
