@@ -20,7 +20,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ev-application.h"
+#include "ev-utils.h"
+#include "ev-document-types.h"
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -95,7 +101,7 @@ is_window_empty (const EvWindow *ev_window, gconstpointer dummy)
 		: -1;
 }
 
-static EvWindow *
+EvWindow *
 ev_application_get_empty_window (EvApplication *application)
 {
 	GList *node;
@@ -113,7 +119,7 @@ ev_application_open (EvApplication *application, GError *err)
 {
 	EvWindow *ev_window;
 	GtkWidget *chooser;
-	GtkFileFilter *both_filter, *pdf_filter, *ps_filter, *pixbuf_filter, *all_filter;
+	static char *folder = NULL;
 
 	ev_window = ev_application_get_empty_window (application);
 
@@ -125,46 +131,31 @@ ev_application_open (EvApplication *application, GError *err)
 					       GTK_STOCK_OPEN, GTK_RESPONSE_OK,
 					       NULL);
 
-	both_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (both_filter,
-				  _("PostScript and PDF Documents"));
-	gtk_file_filter_add_mime_type (both_filter, "application/postscript");
-	gtk_file_filter_add_mime_type (both_filter, "application/x-gzpostscript");
-	gtk_file_filter_add_mime_type (both_filter, "image/x-eps");
-	gtk_file_filter_add_mime_type (both_filter, "application/pdf");
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), both_filter);
+	if (folder) {
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (chooser),
+						         folder);
+    	}
 
-	ps_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (ps_filter, _("PostScript Documents"));
-	gtk_file_filter_add_mime_type (ps_filter, "application/postscript");
-	gtk_file_filter_add_mime_type (both_filter, "application/x-gzpostscript");
-	gtk_file_filter_add_mime_type (ps_filter, "image/x-eps");
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), ps_filter);
-
-	pdf_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (pdf_filter, _("PDF Documents"));
-	gtk_file_filter_add_mime_type (pdf_filter, "application/pdf");
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), pdf_filter);
-
-	pixbuf_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (pixbuf_filter, _("Images"));
-	gtk_file_filter_add_pixbuf_formats (pixbuf_filter);
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), pixbuf_filter);
-	
-	all_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (all_filter, _("All Files"));
-	gtk_file_filter_add_pattern (all_filter, "*");
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), all_filter);
-	
-	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (chooser), both_filter);
+	ev_document_types_add_filters (chooser);
+	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (chooser), TRUE);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (chooser), FALSE);
 
 	if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_OK) {
-		char *uri;
+		GSList *uris;
 
-		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser));
-		ev_window_open (ev_window, uri);
-		gtk_widget_show (GTK_WIDGET (ev_window));
-		g_free (uri);
+		uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (chooser));
+
+		if (folder != NULL)
+			g_free (folder);
+				
+		folder = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (chooser));
+
+		ev_window_open_uri_list (ev_window, uris);
+		
+		g_slist_free (uris);
+	} else {
+		if (!GTK_WIDGET_VISIBLE (ev_window))
+			gtk_widget_destroy (GTK_WIDGET (ev_window));
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (chooser));
