@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-page-action.c,v 1.16 2005/05/11 09:42:22 marco Exp $
+ *  $Id: ev-page-action.c,v 1.21 2005/06/19 13:10:20 nshmyrev Exp $
  */
 
 #include "config.h"
 
 #include "ev-page-action.h"
+#include "ev-page-cache.h"
 #include "ev-window.h"
 #include "ev-document-links.h"
 #include "ev-marshal.h"
@@ -180,10 +181,16 @@ page_changed_cb (EvPageCache        *page_cache,
 	g_assert (proxy);
 	
 	if (page_cache != NULL && page >= 0) {
+	
+		gtk_entry_set_width_chars (GTK_ENTRY (proxy->entry), 
+					   CLAMP (ev_page_cache_get_max_label_chars (page_cache), 
+					   4, 12));	
+		
 		gchar *page_label = ev_page_cache_get_page_label (page_cache, page);
 		gtk_entry_set_text (GTK_ENTRY (proxy->entry), page_label);
 		gtk_editable_set_position (GTK_EDITABLE (proxy->entry), -1);
 		g_free (page_label);
+		
 	} else {
 		gtk_entry_set_text (GTK_ENTRY (proxy->entry), "");
 	}
@@ -299,6 +306,9 @@ build_new_tree_cb (GtkTreeModel *model,
 				    -1);
 	}
 	
+	if (link)
+		g_object_unref (link);
+	
 	return FALSE;
 }
 
@@ -337,7 +347,12 @@ match_selected_cb (GtkEntryCompletion *completion,
 			    EV_DOCUMENT_LINKS_COLUMN_LINK, &link,
 			    -1);
 
-	g_signal_emit (proxy, signals[ACTIVATE_LINK], 0, link);
+	g_signal_emit (proxy, widget_signals[WIDGET_ACTIVATE_LINK], 0, link);
+
+	if (link)
+		g_object_unref (link);
+
+	gtk_tree_iter_free (iter);
 	
 	return TRUE;
 }
@@ -361,6 +376,11 @@ display_completion_text (GtkCellLayout      *cell_layout,
 			    -1);
 
 	g_object_set (renderer, "text", ev_link_get_title (link), NULL);
+
+	if (link)
+		g_object_unref (link);
+	
+	gtk_tree_iter_free (iter);
 }
 
 static gboolean
@@ -382,8 +402,12 @@ match_completion (GtkEntryCompletion *completion,
 			    -1);
 
 
-	if (link)
+	if (link) {
 		text = ev_link_get_title (link);
+		g_object_unref (link);
+	}
+
+	gtk_tree_iter_free (iter);
 
 	if (text && key ) {
 		gchar *normalized_text;
@@ -454,6 +478,8 @@ update_model (EvPageAction *page, GParamSpec *pspec, EvPageActionWidget *proxy)
 						    (GtkCellLayoutDataFunc) display_completion_text,
 						    proxy, NULL);
 		gtk_entry_set_completion (GTK_ENTRY (proxy->entry), completion);
+
+		g_object_unref (model);
 	}
 }
 
@@ -563,7 +589,7 @@ ev_page_action_set_document (EvPageAction *page, EvDocument *document)
 	EvPageCache *page_cache = NULL;
 
 	if (document)
-		page_cache = ev_document_get_page_cache (document);
+		page_cache = ev_page_cache_get (document);
 	
 	g_object_set (page,
 		      "page-cache", page_cache,
