@@ -27,6 +27,7 @@
 #include <gtk/gtkwindow.h>
 
 #include "ev-link.h"
+#include "ev-page-cache.h"
 
 G_BEGIN_DECLS
 
@@ -51,15 +52,16 @@ struct _EvWindowClass {
 };
 
 GType		ev_window_get_type	(void);
-void		ev_window_open		(EvWindow       *ev_window,
+void		ev_window_open_uri	(EvWindow       *ev_window,
 					 const char     *uri);
+void           ev_window_open_uri_list (EvWindow       *ev_window,
+					 GSList         *uris);
 void		ev_window_open_page_label	(EvWindow       *ev_window,
 						 const char *label);
 gboolean	ev_window_is_empty	(const EvWindow *ev_window);
 void		ev_window_print_range   (EvWindow       *ev_window,
 					 int             first_page,
 					 int		 last_page);
-
 G_END_DECLS
 
 #endif /* !EV_WINDOW_H */
